@@ -242,7 +242,7 @@ pub fn all_paths<T: AsRef<Path>>(path: T) -> RvResult<Vec<PathBuf>>
 ///
 /// assert!(vfs::set_memfs().is_ok());
 /// let file = vfs::root().mash("file");
-/// let mut f = vfs::create(&file).unwrap();
+/// let mut f = vfs::write(&file).unwrap();
 /// f.write_all(b"foobar").unwrap();
 /// f.flush().unwrap();
 /// let mut f = vfs::append(&file).unwrap();
@@ -426,31 +426,6 @@ pub fn copy_b<T: AsRef<Path>, U: AsRef<Path>>(src: T, dst: U) -> RvResult<Copier
     VFS.read().unwrap().clone().copy_b(src, dst)
 }
 
-/// Opens a file in write-only mode
-///
-/// * Creates a file if it does not exist or truncates it if it does
-///
-/// ### Errors
-/// * PathError::IsNotDir(PathBuf) when the given path's parent exists but is not a directory
-/// * PathError::DoesNotExist(PathBuf) when the given path's parent doesn't exist
-/// * PathError::IsNotFile(PathBuf) when the given path exists but is not a file
-///
-/// ### Examples
-/// ```
-/// use rivia_vfs::prelude::*;
-///
-/// assert!(vfs::set_memfs().is_ok());
-/// let file = vfs::root().mash("file");
-/// let mut f = vfs::create(&file).unwrap();
-/// f.write_all(b"foobar").unwrap();
-/// f.flush().unwrap();
-/// assert_read_all!(&file, "foobar");
-/// ```
-pub fn create<T: AsRef<Path>>(path: T) -> RvResult<Box<dyn Write>>
-{
-    VFS.read().unwrap().clone().create(path)
-}
-
 /// Returns the current working directory
 ///
 /// ### Examples
@@ -878,32 +853,6 @@ pub fn move_p<T: AsRef<Path>, U: AsRef<Path>>(src: T, dst: U) -> RvResult<()>
     VFS.read().unwrap().clone().move_p(src, dst)
 }
 
-/// Attempts to open a file in readonly mode
-///
-/// * Provides a handle to a Read + Seek implementation
-/// * Handles path expansion and absolute path resolution
-///
-/// ### Errors
-/// * PathError::IsNotFile(PathBuf) when the given path isn't a file
-/// * PathError::DoesNotExist(PathBuf) when the given path doesn't exist
-///
-/// ### Examples
-/// ```
-/// use rivia_vfs::prelude::*;
-///
-/// assert!(vfs::set_memfs().is_ok());
-/// let file = vfs::root().mash("file");
-/// assert_write_all!(&file, b"foobar 1");
-/// let mut file = vfs::open(&file).unwrap();
-/// let mut buf = String::new();
-/// file.read_to_string(&mut buf);
-/// assert_eq!(buf, "foobar 1".to_string());
-/// ```
-pub fn open<T: AsRef<Path>>(path: T) -> RvResult<Box<dyn ReadSeek>>
-{
-    VFS.read().unwrap().clone().open(path)
-}
-
 /// Returns the (user ID, group ID) of the owner of this file
 ///
 /// * Handles path expansion and absolute path resolution
@@ -945,6 +894,32 @@ pub fn paths<T: AsRef<Path>>(path: T) -> RvResult<Vec<PathBuf>>
     VFS.read().unwrap().clone().paths(path)
 }
 
+/// Attempts to open a file in readonly mode
+///
+/// * Provides a handle to a Read + Seek implementation
+/// * Handles path expansion and absolute path resolution
+///
+/// ### Errors
+/// * PathError::IsNotFile(PathBuf) when the given path isn't a file
+/// * PathError::DoesNotExist(PathBuf) when the given path doesn't exist
+///
+/// ### Examples
+/// ```
+/// use rivia_vfs::prelude::*;
+///
+/// assert!(vfs::set_memfs().is_ok());
+/// let file = vfs::root().mash("file");
+/// assert_write_all!(&file, b"foobar 1");
+/// let mut file = vfs::read(&file).unwrap();
+/// let mut buf = String::new();
+/// file.read_to_string(&mut buf);
+/// assert_eq!(buf, "foobar 1".to_string());
+/// ```
+pub fn read<T: AsRef<Path>>(path: T) -> RvResult<Box<dyn ReadSeek>>
+{
+    VFS.read().unwrap().clone().read(path)
+}
+
 /// Read all data from the given file and return it as a String
 ///
 /// * Handles path expansion and absolute path resolution
@@ -967,6 +942,28 @@ pub fn read_all<T: AsRef<Path>>(path: T) -> RvResult<String>
     VFS.read().unwrap().clone().read_all(path)
 }
 
+/// Read the given file and returns it as lines in a vector
+///
+/// * Handles path expansion and absolute path resolution
+///
+/// ### Errors
+/// * PathError::IsNotFile(PathBuf) when the given path isn't a file
+/// * PathError::DoesNotExist(PathBuf) when the given path doesn't exist
+///
+/// ### Examples
+/// ```
+/// use rivia_vfs::prelude::*;
+///
+/// assert!(vfs::set_memfs().is_ok());
+/// let file = vfs::root().mash("file");
+/// assert_write_all!(&file, "1\n2");
+/// assert_eq!(vfs::read_lines(&file).unwrap(), vec!["1".to_string(), "2".to_string()]);
+/// ```
+pub fn read_lines<T: AsRef<Path>>(path: T) -> RvResult<Vec<String>>
+{
+    VFS.read().unwrap().clone().read_lines(path)
+}
+
 /// Returns the relative path of the target the link points to
 ///
 /// * Handles path expansion and absolute path resolution
@@ -1139,6 +1136,31 @@ pub fn uid<T: AsRef<Path>>(path: T) -> RvResult<u32>
     VFS.read().unwrap().clone().uid(path)
 }
 
+/// Opens a file in write-only mode
+///
+/// * Creates a file if it does not exist or truncates it if it does
+///
+/// ### Errors
+/// * PathError::IsNotDir(PathBuf) when the given path's parent exists but is not a directory
+/// * PathError::DoesNotExist(PathBuf) when the given path's parent doesn't exist
+/// * PathError::IsNotFile(PathBuf) when the given path exists but is not a file
+///
+/// ### Examples
+/// ```
+/// use rivia_vfs::prelude::*;
+///
+/// assert!(vfs::set_memfs().is_ok());
+/// let file = vfs::root().mash("file");
+/// let mut f = vfs::write(&file).unwrap();
+/// f.write_all(b"foobar").unwrap();
+/// f.flush().unwrap();
+/// assert_read_all!(&file, "foobar");
+/// ```
+pub fn write<T: AsRef<Path>>(path: T) -> RvResult<Box<dyn Write>>
+{
+    VFS.read().unwrap().clone().write(path)
+}
+
 /// Write the given data to to the target file
 ///
 /// * Handles path expansion and absolute path resolution
@@ -1165,6 +1187,32 @@ pub fn write_all<T: AsRef<Path>, U: AsRef<[u8]>>(path: T, data: U) -> RvResult<(
     VFS.read().unwrap().clone().write_all(path, data)
 }
 
+/// Write the given lines to to the target file
+///
+/// * Handles path expansion and absolute path resolution
+/// * Create the file first if it doesn't exist or truncating it first if it does
+///
+/// ### Errors
+/// * PathError::IsNotDir(PathBuf) when the given path's parent exists but is not a directory
+/// * PathError::DoesNotExist(PathBuf) when the given path's parent doesn't exist
+/// * PathError::IsNotFile(PathBuf) when the given path exists but is not a file
+///
+/// ### Examples
+/// ```
+/// use rivia_vfs::prelude::*;
+///
+/// assert!(vfs::set_memfs().is_ok());
+/// let file = vfs::root().mash("file");
+/// assert_no_file!(&file);
+/// assert!(vfs::write_lines(&file, &["1", "2"]).is_ok());
+/// assert_is_file!(&file);
+/// assert_read_all!(&file, "1\n2".to_string());
+/// ```
+pub fn write_lines<T: AsRef<Path>, U: AsRef<str>>(path: T, lines: &[U]) -> RvResult<()>
+{
+    VFS.read().unwrap().clone().write_lines(path, lines)
+}
+
 // Unit tests
 // -------------------------------------------------------------------------------------------------
 #[cfg(test)]
@@ -1226,7 +1274,7 @@ mod tests
     {
         let tmpdir = assert_memfs_setup!();
         let file = tmpdir.mash("file");
-        let mut f = vfs::create(&file).unwrap();
+        let mut f = vfs::write(&file).unwrap();
         f.write_all(b"foobar").unwrap();
         f.flush().unwrap();
         let mut f = vfs::append(&file).unwrap();
@@ -1323,18 +1371,6 @@ mod tests
         assert_remove_all!(&tmpdir);
     }
 
-    #[test]
-    fn test_create()
-    {
-        let tmpdir = assert_memfs_setup!();
-        let file = tmpdir.mash("file");
-        let mut f = vfs::create(&file).unwrap();
-        f.write_all(b"foobar").unwrap();
-        f.flush().unwrap();
-        assert_read_all!(&file, "foobar");
-        assert_remove_all!(&tmpdir);
-    }
-
     #[test]
     fn test_cwd()
     {
@@ -1573,19 +1609,6 @@ mod tests
         assert_remove_all!(&tmpdir);
     }
 
-    #[test]
-    fn test_open()
-    {
-        let tmpdir = assert_memfs_setup!();
-        let file = tmpdir.mash("file");
-        assert_write_all!(&file, b"foobar 1");
-        let mut file = vfs::open(&file).unwrap();
-        let mut buf = String::new();
-        assert!(file.read_to_string(&mut buf).is_ok());
-        assert_eq!(buf, "foobar 1".to_string());
-        assert_remove_all!(&tmpdir);
-    }
-
     #[test]
     fn test_owner()
     {
@@ -1607,6 +1630,19 @@ mod tests
         assert_remove_all!(&tmpdir);
     }
 
+    #[test]
+    fn test_read()
+    {
+        let tmpdir = assert_memfs_setup!();
+        let file = tmpdir.mash("file");
+        assert_write_all!(&file, b"foobar 1");
+        let mut file = vfs::read(&file).unwrap();
+        let mut buf = String::new();
+        assert!(file.read_to_string(&mut buf).is_ok());
+        assert_eq!(buf, "foobar 1".to_string());
+        assert_remove_all!(&tmpdir);
+    }
+
     #[test]
     fn test_read_all()
     {
@@ -1618,6 +1654,16 @@ mod tests
         assert_remove_all!(&tmpdir);
     }
 
+    #[test]
+    fn test_read_lines()
+    {
+        let tmpdir = assert_memfs_setup!();
+        let file = tmpdir.mash("file");
+        assert_write_all!(&file, "1\n2");
+        assert_eq!(vfs::read_lines(&file).unwrap(), vec!["1".to_string(), "2".to_string()]);
+        assert_remove_all!(&tmpdir);
+    }
+
     #[test]
     fn test_readlink()
     {
@@ -1703,6 +1749,18 @@ mod tests
         assert_eq!(vfs::uid(vfs::root()).unwrap(), 1000);
     }
 
+    #[test]
+    fn test_write()
+    {
+        let tmpdir = assert_memfs_setup!();
+        let file = tmpdir.mash("file");
+        let mut f = vfs::write(&file).unwrap();
+        f.write_all(b"foobar").unwrap();
+        f.flush().unwrap();
+        assert_read_all!(&file, "foobar");
+        assert_remove_all!(&tmpdir);
+    }
+
     #[test]
     fn test_write_all()
     {
@@ -1714,4 +1772,16 @@ mod tests
         assert_read_all!(&file, "foobar 1");
         assert_remove_all!(&tmpdir);
     }
+
+    #[test]
+    fn test_write_lines()
+    {
+        let tmpdir = assert_memfs_setup!();
+        let file = tmpdir.mash("file");
+        assert_no_file!(&file);
+        assert!(vfs::write_lines(&file, &["1", "2"]).is_ok());
+        assert_is_file!(&file);
+        assert_read_all!(&file, "1\n2");
+        assert_remove_all!(&tmpdir);
+    }
 }
